/* Copyright (C) 2024 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#include "ParFiles.h"

using namespace cbm::algo;

ParFiles::ParFiles(uint32_t runId)
{
  bool is2024 = 2724 <= runId;

  if (is2024) {
    sts.readout   = "StsReadout_mcbm2024.yaml";
    sts.chanMask  = "StsChannelMaskSet_mcbm2024.yaml";
    sts.walkMap   = "StsWalkMap_mcbm2024.yaml";
    sts.hitfinder = "StsHitfinder_mcbm2024.yaml";

    tof.calibrate = "TofCalibratePar_mcbm2024.yaml";
    tof.hitfinder = "TofHitfinderPar_mcbm2024.yaml";

    trd.readout     = "TrdReadoutSetup_mcbm2024.yaml";
    trd.readout2d   = "TrdReadout2DSetup_mcbm2022.yaml";  // TODO: no new readout for TRD2D?
    trd.hitfinder   = "TrdHitfinderPar_mcbm2024.yaml";
    trd.hitfinder2d = "TrdHitfinder2DPar_mcbm2024.yaml";

    ca.mainConfig = "TrackingChainConfig_mcbm2024.yaml";
  }
  else {  // Assume 2022 setup
    sts.readout   = "StsReadout_mcbm2022.yaml";
    sts.chanMask  = "StsChannelMaskSet_mcbm2022.yaml";
    sts.walkMap   = "StsWalkMap_mcbm2022.yaml";
    sts.hitfinder = "StsHitfinder_mcbm2022.yaml";

    tof.calibrate = "TofCalibratePar_mcbm2022.yaml";
    tof.hitfinder = "TofHitfinderPar_mcbm2022.yaml";

    trd.readout     = "TrdReadoutSetup_mcbm2022.yaml";
    trd.readout2d   = "TrdReadout2DSetup_mcbm2022.yaml";
    trd.hitfinder   = "TrdHitfinderPar_mcbm2022.yaml";
    trd.hitfinder2d = "TrdHitfinder2DPar_mcbm2022.yaml";

    ca.mainConfig = "TrackingChainConfig_mcbm2022.yaml";
  }
}
